@@ -760,7 +760,7 @@ class DataVars(object):
         self.__LevelsVar.append((self.__levelNumber, nameVar))
         self.__levelNumber += 1
         #nameMethod = "get_" + nameVar
-        if self.__dict__.has_key(nameVar):
+        if hasattr(self, nameVar):
            ret = self.__getattribute__(nameVar).Get()
         elif self.__findVarData(nameVar):
             dictVar, methodFill =self.__findVarData(nameVar)
@@ -790,7 +790,7 @@ class DataVars(object):
 
     def __Set(self, nameVar, value, force=False):
         nameMethod = "get_" +nameVar
-        if not self.__dict__.has_key(nameVar) and self.__findVarData(nameVar):
+        if not hasattr(self, nameVar) and self.__findVarData(nameVar):
             dictVar, methodFill =self.__findVarData(nameVar)
             varobj = var(self)
             # Устанавливаем аттрибуты
@@ -798,7 +798,7 @@ class DataVars(object):
             if methodFill:
                 varobj.Fill = methodFill
             self.__setattr__(nameVar, varobj)
-        if self.__dict__.has_key(nameVar):
+        if hasattr(self, nameVar):
             if not force and "r" in getattr(self, nameVar).mode:
                 print _("Attempt to rewrite a variable for reading:%s")\
                       %nameVar
@@ -855,11 +855,11 @@ class DataVars(object):
 
         vname - имя переменной
         """
-        if self.__dict__.has_key(vname):
-            if self.__dict__[vname].service == 'Global':
+        if hasattr(self, vname):
+            if getattr(self, vname).service == 'Global':
                 return 'calculate'
             else:
-                return self.__dict__[vname].service.lower()
+                return getattr(self, vname).service.lower()
 
     def __writeVarValue(self, vname, val, location, header):
         '''Записать значение в calculate.ini
@@ -907,9 +907,10 @@ class DataVars(object):
         Параметры:
         vname       имя переменной
         location    расположение ini файла ('default', 'local', 'remote')
+        header      раздел ini файла ('client', 'server', 'calculate')
 
         Возвращаемые значение:
-        True        удалено успешна
+        True        удалено успешно
         False       удаление не удалсь
         '''
         # получаем все пути до ini файлов
@@ -932,6 +933,9 @@ class DataVars(object):
         # Получаем секцию конфигурационного файла
         if not header:
             header = self.__getSection(vname)
+            if not header:
+                self.Get(vname)
+                header = self.__getSection(vname)
         # Удаляем переменную
         retDelVar = config.delVar(header, vname)
         retDelArea = True
@@ -1049,11 +1053,7 @@ class DataVars(object):
         '''Заполнить конфигурацию переменных для инсталятора'''
         self.Set('setup_pass','install',True)
 
-    #def defined(self, vname):
-        #if vname:
-            #if self.__dict__.has_key(vname):
-                #return True
-        #return False
+
     def defined(self, vname):
         return True
 
@@ -1062,7 +1062,7 @@ class DataVars(object):
     def exists(self, nameVar):
         """ Определяет существует ли переменная с таким имененм
         """
-        if self.__dict__.has_key(nameVar):
+        if hasattr(self, nameVar):
             return True
         foundVar = False
         # Ищем переменную в импортируемых модулях
