@@ -86,3 +86,6 @@ class Data:
 
     # Действие программы 
     cl_pass_run = {'mode':"w"}
+    
+    #Логин пользователя
+    ur_login = {'mode':"w"}
